@@ -1,8 +1,12 @@
 from typing import List, Union, Optional
 
 from pydantic import BaseModel, Field
-from typing_extensions import Annotated
-from typing_extensions import Literal
+
+try:
+    # TODO py37 & py38 required
+    from typing import Annotated, Literal
+except ImportError:
+    from typing_extensions import Annotated, Literal
 
 
 class Transport(BaseModel):
